# OpenFisca-UK Variable Statistics

All statistics generated from the uprated (to 2020) 2018-19 Family Resources Survey, with simulation turned on.


- benunit_rent:
  - Type: float
  - Entity: benunit
  - Description: Benefit unit rent
  - Mean: 2087.7001555800266
  - Median: -52.0
  - Stddev: 3778.230224609375
  - Non-zero count: 10896012.0


- childcare_expenses:
  - Type: float
  - Entity: person
  - Description: Cost of childcare
  - Mean: 112.0387608124459
  - Median: 0.0
  - Stddev: 881.9299926757812
  - Non-zero count: 2448366.0


- council_tax:
  - Type: float
  - Entity: household
  - Description: Council Tax
  - Mean: 449.2329959998904
  - Median: -1.0399999618530273
  - Stddev: 722.9871826171875
  - Non-zero count: 8473529.0


- council_tax_band:
  - Type: Categorical
  - Entity: household
  - Description: Council Tax Band


- employer_pension_contributions:
  - Type: float
  - Entity: person
  - Description: Employer pension contributions
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- family_rent:
  - Type: float
  - Entity: benunit
  - Description: Gross rent for the family
  - Mean: 2057.4581300850614
  - Median: -52.0
  - Stddev: 3968.763427734375
  - Non-zero count: 9879081.0


- housing_costs:
  - Type: float
  - Entity: household
  - Description: Total housing costs
  - Mean: 4118.796750948684
  - Median: 2964.0
  - Stddev: 4262.90771484375
  - Non-zero count: 27890292.0


- housing_service_charges:
  - Type: float
  - Entity: household
  - Description: Housing service charges
  - Mean: 66.2688343148919
  - Median: 0.0
  - Stddev: 339.3194274902344
  - Non-zero count: 2515150.0


- maintenance_expenses:
  - Type: float
  - Entity: person
  - Description: Maintenance expenses
  - Mean: 42.05121589349538
  - Median: 0.0
  - Stddev: 621.5613403320312
  - Non-zero count: 727856.0


- mortgage:
  - Type: float
  - Entity: household
  - Description: Total mortgage payments
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- mortgage_capital_repayment:
  - Type: float
  - Entity: household
  - Description: Mortgage payments
  - Mean: 2275.8240874738376
  - Median: 0.0
  - Stddev: 5618.78857421875
  - Non-zero count: 7987042.0


- mortgage_interest_repayment:
  - Type: float
  - Entity: household
  - Description: Total mortgage payments
  - Mean: 878.4845800462065
  - Median: -52.0
  - Stddev: 2093.639404296875
  - Non-zero count: 7964552.0


- occupational_pension_contributions:
  - Type: float
  - Entity: person
  - Description: Occupational pension contributions
  - Mean: 471.64221164150297
  - Median: 0.0
  - Stddev: 1300.0899658203125
  - Non-zero count: 18105069.0


- personal_rent:
  - Type: float
  - Entity: person
  - Description: Personal rent
  - Mean: 1105.002381482025
  - Median: 0.0
  - Stddev: 3035.36083984375
  - Non-zero count: 9879081.0


- private_pension_contributions:
  - Type: float
  - Entity: person
  - Description: Private pension contributions
  - Mean: 29.046179296053264
  - Median: 0.0
  - Stddev: 172.59417724609375
  - Non-zero count: 2052813.0


- rent:
  - Type: float
  - Entity: household
  - Description: Gross rent for the household
  - Mean: 2587.238890527773
  - Median: -52.0
  - Stddev: 4221.08203125
  - Non-zero count: 9879081.0


- water_and_sewerage_charges:
  - Type: float
  - Entity: household
  - Description: Water and sewerage charges
  - Mean: 376.4165690513558
  - Median: 358.79998779296875
  - Stddev: 252.75648498535156
  - Non-zero count: 26722365.0


- weekly_childcare_expenses:
  - Type: float
  - Entity: person
  - Description: Average cost of childcare
  - Mean: 2.1545904001483804
  - Median: 0.0
  - Stddev: 16.967021942138672
  - Non-zero count: 2448366.0


- weekly_rent:
  - Type: float
  - Entity: household
  - Description: Weekly average rent
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- base_net_income:
  - Type: float
  - Entity: person
  - Description: Existing net income for the person to use as a base in microsimulation
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- capital_income:
  - Type: float
  - Entity: person
  - Description: Income from savings or dividends
  - Mean: 236.0087318821451
  - Median: 0.0
  - Stddev: 2069.235107421875
  - Non-zero count: 22732579.0


- earned_income:
  - Type: float
  - Entity: person
  - Description: Total earned income
  - Mean: 16015.051340269645
  - Median: 6982.14013671875
  - Stddev: 25153.765625
  - Non-zero count: 39035503.0


- employment_status:
  - Type: Categorical
  - Entity: person
  - Description: Employment status of the person


- equiv_household_net_income:
  - Type: float
  - Entity: household
  - Description: Equivalised household net income
  - Mean: 45026.95577567806
  - Median: 35655.24800066393
  - Stddev: 34065.51171875
  - Non-zero count: 27776514.0


- equiv_household_net_income_ahc:
  - Type: float
  - Entity: household
  - Description: Equivalised household net income, after housing costs
  - Mean: 44970.95322598284
  - Median: 34801.12308533462
  - Stddev: 38571.265625
  - Non-zero count: 27251560.0


- gross_income:
  - Type: float
  - Entity: person
  - Description: Gross income, including benefits
  - Mean: 18828.31199189229
  - Median: 13036.912838322021
  - Stddev: 25295.21875
  - Non-zero count: 48068431.0


- hours_worked:
  - Type: float
  - Entity: person
  - Description: Total amount of hours worked by this person
  - Mean: 887.9178706358532
  - Median: 0.0
  - Stddev: 1034.43212890625
  - Non-zero count: 31481751.0


- household_net_income:
  - Type: float
  - Entity: household
  - Description: Household net income
  - Mean: 35417.9462027196
  - Median: 28531.93236770073
  - Stddev: 26541.068359375
  - Non-zero count: 27776514.0


- household_net_income_ahc:
  - Type: float
  - Entity: household
  - Description: Household net income, after housing costs
  - Mean: 31299.14944074298
  - Median: 24797.63741494455
  - Stddev: 26069.375
  - Non-zero count: 27251560.0


- in_work:
  - Type: bool
  - Entity: person
  - Description: Worked some hours
  - Mean: 0.4798607486833267
  - Median: 0.0
  - Stddev: 0.49602900033758385
  - Non-zero count: 31485873.0


- lump_sum_income:
  - Type: float
  - Entity: person
  - Description: Lump sum income
  - Mean: 77.29743315430557
  - Median: -1.0
  - Stddev: 1944.638427734375
  - Non-zero count: 242645.0


- maintenance_income:
  - Type: float
  - Entity: person
  - Description: Maintenance payments
  - Mean: 35.933107380530444
  - Median: 0.0
  - Stddev: 515.779296875
  - Non-zero count: 747849.0


- market_income:
  - Type: float
  - Entity: person
  - Description: Market income
  - Mean: 16072.64330456326
  - Median: 7227.776706299325
  - Stddev: 25574.845703125
  - Non-zero count: 40657526.0


- miscellaneous_income:
  - Type: float
  - Entity: person
  - Description: Income from other sources
  - Mean: -142.57390163930117
  - Median: -208.0
  - Stddev: 836.8568115234375
  - Non-zero count: 747462.0


- net_income:
  - Type: float
  - Entity: person
  - Description: Net income
  - Mean: 15313.011547479256
  - Median: 12802.51214725439
  - Stddev: 17011.892578125
  - Non-zero count: 48068431.0


- private_transfer_income:
  - Type: float
  - Entity: person
  - Description: Private transfers
  - Mean: -126.43649498680587
  - Median: -312.0
  - Stddev: 1242.374755859375
  - Non-zero count: 1170129.0


- sublet_income:
  - Type: float
  - Entity: person
  - Description: Income received from sublet agreements
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- weekly_hours:
  - Type: float
  - Entity: person
  - Description: Average weekly hours for the year
  - Mean: 17.0753436666394
  - Median: 0.0
  - Stddev: 19.89482307434082
  - Non-zero count: 31481751.0


- disability_premium:
  - Type: float
  - Entity: benunit
  - Description: Disability premium
  - Mean: 165.3213980322027
  - Median: 0.0
  - Stddev: 637.502197265625
  - Non-zero count: 2682027.0


- enhanced_disability_premium:
  - Type: float
  - Entity: benunit
  - Description: Enhanced disability premium
  - Mean: 0.2874294489588408
  - Median: 0.0
  - Stddev: 23.07422637939453
  - Non-zero count: 8557.0


- is_disabled_for_benefits:
  - Type: bool
  - Entity: person
  - Description: Whether this person is disabled for benefits purposes
  - Mean: 0.04335382409684283
  - Median: 0.0
  - Stddev: 0.22247959311895188
  - Non-zero count: 2844644.0


- is_enhanced_disabled_for_benefits:
  - Type: bool
  - Entity: person
  - Description: Whether meets the middle disability benefit entitlement
  - Mean: 0.00013041304036522113
  - Median: 0.0
  - Stddev: 0.014413418520820459
  - Non-zero count: 8557.0


- is_severely_disabled_for_benefits:
  - Type: bool
  - Entity: person
  - Description: Whether this person is severely disabled for benefits purposes
  - Mean: 0.0291951011393744
  - Median: 0.0
  - Stddev: 0.1854097664369735
  - Non-zero count: 1915625.0


- num_disabled_adults:
  - Type: int
  - Entity: benunit
  - Description: Number of disabled adults
  - Mean: 0.0792900810681304
  - Median: 0.0
  - Stddev: 0.3114640053342676
  - Non-zero count: 2682027.0


- num_disabled_children:
  - Type: int
  - Entity: benunit
  - Description: Number of disabled children
  - Mean: 0.0006841991067925526
  - Median: 0.0
  - Stddev: 0.028898573901527055
  - Non-zero count: 24111.0


- num_enhanced_disabled_adults:
  - Type: int
  - Entity: benunit
  - Description: Number of enhanced disabled adults
  - Mean: 0.00024282243610069564
  - Median: 0.0
  - Stddev: 0.019893740353175038
  - Non-zero count: 8557.0


- num_enhanced_disabled_children:
  - Type: int
  - Entity: benunit
  - Description: Number of enhanced disabled children
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- num_severely_disabled_adults:
  - Type: int
  - Entity: benunit
  - Description: Number of severely disabled adults
  - Mean: 0.05354148166010977
  - Median: 0.0
  - Stddev: 0.26111002390157856
  - Non-zero count: 1815863.0


- num_severely_disabled_children:
  - Type: int
  - Entity: benunit
  - Description: Number of severely disabled children
  - Mean: 0.00031595009974817636
  - Median: 0.0
  - Stddev: 0.020969382157258923
  - Non-zero count: 11134.0


- severe_disability_premium:
  - Type: float
  - Entity: benunit
  - Description: Severe disability premium
  - Mean: 255.25457289328594
  - Median: 0.0
  - Stddev: 1282.4947509765625
  - Non-zero count: 1815863.0


- carer_premium:
  - Type: float
  - Entity: benunit
  - Description: Carer premium
  - Mean: 36.40777364374575
  - Median: 0.0
  - Stddev: 284.046142578125
  - Non-zero count: 657949.0


- is_carer_for_benefits:
  - Type: bool
  - Entity: person
  - Description: Whether this person is a carer for benefits purposes
  - Mean: 0.01010361961492597
  - Median: 0.0
  - Stddev: 0.10671487700786582
  - Non-zero count: 662945.0


- num_carers:
  - Type: int
  - Entity: benunit
  - Description: The number of carers for benefits purposes in the family
  - Mean: 0.018812424903678352
  - Median: 0.0
  - Stddev: 0.1483154747090402
  - Non-zero count: 657949.0


- benefits:
  - Type: float
  - Entity: person
  - Description: Total benefits
  - Mean: 2623.1141000247867
  - Median: 0.0
  - Stddev: 4918.82421875
  - Non-zero count: 23809308.0


- benefits_modelling:
  - Type: float
  - Entity: person
  - Description: Difference between reported and simulated benefits for this person
  - Mean: 45.020530233661056
  - Median: 0.0
  - Stddev: 2409.662109375
  - Non-zero count: 9931654.0


- benefits_premiums:
  - Type: float
  - Entity: benunit
  - Description: Value of premiums for disability and carer status
  - Mean: 457.2711789731099
  - Median: 0.0
  - Stddev: 1763.608154296875
  - Non-zero count: 3749694.0


- benefits_reported:
  - Type: float
  - Entity: person
  - Description: Total simulated
  - Mean: 2578.0935641107394
  - Median: 0.0
  - Stddev: 5109.37939453125
  - Non-zero count: 21418568.0


- benunit_weekly_hours:
  - Type: float
  - Entity: benunit
  - Description: Average weekly hours worked by adults in the benefit unit
  - Mean: 31.793419850826332
  - Median: 35.0
  - Stddev: 31.36081886291504
  - Non-zero count: 22380905.0


- claims_legacy_benefits:
  - Type: bool
  - Entity: benunit
  - Description: Whether this family is imputed to claim legacy benefits over Universal Credit
  - Mean: 0.4089037030974858
  - Median: 0.0
  - Stddev: 0.491968164818645
  - Non-zero count: 14409661.0


- family_benefits:
  - Type: float
  - Entity: person
  - Description: Total simulated family benefits for this person
  - Mean: 876.6894329462741
  - Median: 0.0
  - Stddev: 2778.188720703125
  - Non-zero count: 13555620.0


- family_benefits_reported:
  - Type: float
  - Entity: person
  - Description: Total reported family benefits for this person
  - Mean: 876.3700724375886
  - Median: 0.0
  - Stddev: 3104.98779296875
  - Non-zero count: 10538896.0


- is_QYP:
  - Type: bool
  - Entity: person
  - Description: Whether this person is a qualifying young person for benefits purposes
  - Mean: 0.14833447748918824
  - Median: 0.0
  - Stddev: 0.36686190514836653
  - Non-zero count: 9732908.0


- is_child_or_QYP:
  - Type: bool
  - Entity: person
  - Description: Whether this person is a child or qualifying young person for most benefits
  - Mean: 0.20144518436779715
  - Median: 0.0
  - Stddev: 0.4102249556804412
  - Non-zero count: 13217746.0


- is_couple:
  - Type: bool
  - Entity: benunit
  - Description: Whether this benefit unit contains a joint couple claimant for benefits
  - Mean: 0.4837999097723247
  - Median: 0.0
  - Stddev: 0.4999099531700998
  - Non-zero count: 17048984.0


- is_lone_parent:
  - Type: bool
  - Entity: benunit
  - Description: Whether the family is a lone parent family
  - Mean: 0.06944137105203552
  - Median: 0.0
  - Stddev: 0.26656652776956896
  - Non-zero count: 2447096.0


- is_single:
  - Type: bool
  - Entity: benunit
  - Description: Whether this benefit unit contains a single claimant for benefits
  - Mean: 0.5162000902276753
  - Median: 1.0
  - Stddev: 0.4999099531700998
  - Non-zero count: 18190758.0


- is_single_person:
  - Type: bool
  - Entity: benunit
  - Description: Whether the family is a single person
  - Mean: 0.46940556488750684
  - Median: 0.0
  - Stddev: 0.4977298838221244
  - Non-zero count: 16541731.0


- other_benefits:
  - Type: float
  - Entity: person
  - Description: Income from benefits not modelled or detailed in the model
  - Mean: -45.02053091594635
  - Median: 0.0
  - Stddev: 2409.662109375
  - Non-zero count: 23466392.0


- personal_benefits:
  - Type: float
  - Entity: person
  - Description: Value of personal, non-means-tested benefits
  - Mean: 1746.4246645529374
  - Median: 0.0
  - Stddev: 4030.60009765625
  - Non-zero count: 14095406.0


- personal_benefits_reported:
  - Type: float
  - Entity: person
  - Description: Value of personal, non-means-tested benefits
  - Mean: 1701.7234946651608
  - Median: 0.0
  - Stddev: 3865.2451171875
  - Non-zero count: 14114083.0


- council_tax_benefit:
  - Type: float
  - Entity: benunit
  - Description: CTB
  - Mean: 55.63571787784372
  - Median: -52.0
  - Stddev: 305.2732849121094
  - Non-zero count: 3839052.0


- council_tax_benefit_reported:
  - Type: float
  - Entity: person
  - Description: CTB (reported)
  - Mean: 29.880365413772825
  - Median: 0.0
  - Stddev: 223.2305908203125
  - Non-zero count: 3839052.0


- child_benefit:
  - Type: float
  - Entity: benunit
  - Description: Child Benefit
  - Mean: 343.1901088386003
  - Median: 0.0
  - Stddev: 742.9638671875
  - Non-zero count: 7567098.0


- child_benefit_less_tax_charge:
  - Type: float
  - Entity: benunit
  - Description: Child Benefit entitlement, less the High Income Tax Charge
  - Mean: 286.6818290321293
  - Median: 0.0
  - Stddev: 697.5630493164062
  - Non-zero count: 6532573.0


- child_benefit_reported:
  - Type: float
  - Entity: person
  - Description: Child Benefit (reported amount)
  - Mean: 154.51908682136283
  - Median: 0.0
  - Stddev: 537.6369018554688
  - Non-zero count: 6260230.0


- claims_child_benefit:
  - Type: bool
  - Entity: benunit
  - Description: Whether this family is imputed to claim Child Benefit, based on survey response and take-up rates
  - Mean: 0.9602042205643844
  - Median: 1.0
  - Stddev: 0.19530957876671434
  - Non-zero count: 33837349.0


- HB_individual_non_dep_deduction:
  - Type: float
  - Entity: person
  - Description: Non-dependent deduction (individual)
  - Mean: 60.20079093875267
  - Median: 0.0
  - Stddev: 230.160400390625
  - Non-zero count: 3353768.0


- HB_non_dep_deductions:
  - Type: float
  - Entity: benunit
  - Description: Non-dependent deductions
  - Mean: 176.20418973497738
  - Median: 0.0
  - Stddev: 454.4957580566406
  - Non-zero count: 4170689.0


- claims_HB:
  - Type: bool
  - Entity: benunit
  - Description: Whether this family is imputed to claim Housing Benefit
  - Mean: 0.3253310991890917
  - Median: 0.0
  - Stddev: 0.4694560713024851
  - Non-zero count: 11464584.0


- housing_benefit:
  - Type: float
  - Entity: benunit
  - Description: Housing Benefit
  - Mean: 169.50588519734768
  - Median: 0.0
  - Stddev: 902.91552734375
  - Non-zero count: 1591098.0


- housing_benefit_applicable_amount:
  - Type: float
  - Entity: benunit
  - Description: Applicable amount for Housing Benefit
  - Mean: 2093.12147783246
  - Median: 0.0
  - Stddev: 4255.8623046875
  - Non-zero count: 13116397.0


- housing_benefit_applicable_income:
  - Type: float
  - Entity: benunit
  - Description: Relevant income for Housing Benefit means test
  - Mean: 25241.05620010554
  - Median: 19347.584362324396
  - Stddev: 23497.505859375
  - Non-zero count: 32023854.0


- housing_benefit_eligible:
  - Type: bool
  - Entity: benunit
  - Description: Whether eligible for Housing Benefit
  - Mean: 0.37220468299682785
  - Median: 0.0
  - Stddev: 0.4812236580276789
  - Non-zero count: 13116397.0


- housing_benefit_reported:
  - Type: float
  - Entity: person
  - Description: Housing Benefit (reported amount)
  - Mean: 204.32538985259174
  - Median: 0.0
  - Stddev: 1103.3013916015625
  - Non-zero count: 2858159.0


- would_claim_HB:
  - Type: bool
  - Entity: benunit
  - Description: Would claim HB
  - Mean: 0.7972128740329597
  - Median: 1.0
  - Stddev: 0.4005488584828502
  - Non-zero count: 28093576.0


- ESA_income:
  - Type: float
  - Entity: benunit
  - Description: ESA (income-based)
  - Mean: 44.620868846361276
  - Median: 0.0
  - Stddev: 655.0264282226562
  - Non-zero count: 236567.0


- ESA_income_eligible:
  - Type: bool
  - Entity: benunit
  - Description: ESA (income) eligible
  - Mean: 0.017821782009641275
  - Median: 0.0
  - Stddev: 0.14391625994661672
  - Non-zero count: 628035.0


- ESA_income_reported:
  - Type: float
  - Entity: person
  - Description: ESA (income-based) (reported amount)
  - Mean: 62.76392693796924
  - Median: 0.0
  - Stddev: 740.1025390625
  - Non-zero count: 635015.0


- claims_ESA_income:
  - Type: bool
  - Entity: benunit
  - Description: Claims ESA (income)
  - Mean: 0.006713074119555132
  - Median: 0.0
  - Stddev: 0.0905642604059077
  - Non-zero count: 236567.0


- would_claim_ESA_income:
  - Type: bool
  - Entity: benunit
  - Description: Would claim ESA (income)
  - Mean: 0.017821782009641275
  - Median: 0.0
  - Stddev: 0.14391625994661672
  - Non-zero count: 628035.0


- claims_PC:
  - Type: bool
  - Entity: benunit
  - Description: Whether this family is imputed to claim Pension Credit
  - Mean: 0.6172811367347695
  - Median: 1.0
  - Stddev: 0.4848863914922762
  - Non-zero count: 21752828.0


- pension_credit:
  - Type: float
  - Entity: benunit
  - Description: Pension Credit
  - Mean: 92.35590702649647
  - Median: 0.0
  - Stddev: 680.5009155273438
  - Non-zero count: 1498549.0


- pension_credit_GC:
  - Type: float
  - Entity: benunit
  - Description: Pension Credit (Guarantee Credit) amount
  - Mean: 81.57118097976607
  - Median: 0.0
  - Stddev: 666.2617797851562
  - Non-zero count: 1058530.0


- pension_credit_MG:
  - Type: float
  - Entity: benunit
  - Description: Pension Credit (Minimum Guarantee) amount per week
  - Mean: 1507.4917160403286
  - Median: 0.0
  - Stddev: 4431.314453125
  - Non-zero count: 4620343.0


- pension_credit_SC:
  - Type: float
  - Entity: benunit
  - Description: Pension Credit (Savings Credit) amount per week
  - Mean: 10.784725964302927
  - Median: 0.0
  - Stddev: 86.29126739501953
  - Non-zero count: 881585.0


- pension_credit_applicable_income:
  - Type: float
  - Entity: benunit
  - Description: Applicable income for Pension Credit
  - Mean: 27504.547105391386
  - Median: 21004.121326622597
  - Stddev: 25530.90234375
  - Non-zero count: 32196404.0


- pension_credit_eligible:
  - Type: bool
  - Entity: benunit
  - Description: Whether eligible for Pension Credit
  - Mean: 0.1965425002260232
  - Median: 0.0
  - Stddev: 0.42784206772739203
  - Non-zero count: 6926107.0


- pension_credit_reported:
  - Type: float
  - Entity: person
  - Description: Reported amount of Pension Credit
  - Mean: 50.83603003312915
  - Median: 0.0
  - Stddev: 578.7509155273438
  - Non-zero count: 1128441.0


- benefit_cap:
  - Type: float
  - Entity: benunit
  - Description: Benefit cap for the family
  - Mean: inf
  - Median: 13399.8798828125
  - Stddev: nan
  - Non-zero count: 35239742.0


- is_benefit_cap_exempt:
  - Type: bool
  - Entity: benunit
  - Description: Whether exempt from the benefits cap
  - Mean: 0.06935990053502662
  - Median: 0.0
  - Stddev: 0.27794912383646997
  - Non-zero count: 2444225.0


- BRMA_LHA_rate:
  - Type: float
  - Entity: benunit
  - Description: LHA Rate
  - Mean: 5659.844438544578
  - Median: 3766.8798828125
  - Stddev: 2201.6142578125
  - Non-zero count: 35239742.0


- LHA_allowed_bedrooms:
  - Type: float
  - Entity: benunit
  - Description: The number of bedrooms covered by LHA for the benefit unit
  - Mean: 1.4206925805529451
  - Median: 1.0
  - Stddev: 0.9064128398895264
  - Non-zero count: 35239742.0


- LHA_cap:
  - Type: float
  - Entity: benunit
  - Description: Applicable amount for LHA
  - Mean: 1401.557347531679
  - Median: -52.0
  - Stddev: 2310.512939453125
  - Non-zero count: 10896012.0


- LHA_category:
  - Type: Categorical
  - Entity: benunit
  - Description: LHA category for the benefit unit, taking into account LHA rules on the number of LHA-covered bedrooms


- LHA_eligible:
  - Type: float
  - Entity: benunit
  - Description: Whether eligible for Local Housing Allowance
  - Mean: 0.19975935124610164
  - Median: 0.0
  - Stddev: 0.3821133077144623
  - Non-zero count: 7039468.0


- JSA:
  - Type: float
  - Entity: benunit
  - Description: Amount of Jobseeker's Allowance for this family
  - Mean: 21.036919968207965
  - Median: 0.0
  - Stddev: 272.5791015625
  - Non-zero count: 198816.0


- JSA_income:
  - Type: float
  - Entity: benunit
  - Description: JSA (income-based)
  - Mean: 17.985189484513565
  - Median: 0.0
  - Stddev: 248.77642822265625
  - Non-zero count: 173253.0


- JSA_income_applicable_amount:
  - Type: float
  - Entity: benunit
  - Description: Maximum amount of JSA (income-based)
  - Mean: 19.40499229911537
  - Median: 0.0
  - Stddev: 256.1543884277344
  - Non-zero count: 186848.0


- JSA_income_applicable_income:
  - Type: float
  - Entity: benunit
  - Description: Relevant income for JSA (income-based) means test
  - Mean: 25252.396618505514
  - Median: 19223.526873420265
  - Stddev: 24435.818359375
  - Non-zero count: 30587483.0


- JSA_income_eligible:
  - Type: bool
  - Entity: benunit
  - Description: Whether eligible for JSA (income-based)
  - Mean: 0.0214029092494491
  - Median: 0.0
  - Stddev: 0.13403473880742617
  - Non-zero count: 754233.0


- JSA_income_reported:
  - Type: float
  - Entity: person
  - Description: JSA (income-based) (reported amount)
  - Mean: 12.098752020119422
  - Median: 0.0
  - Stddev: 242.96307373046875
  - Non-zero count: 206048.0


- claims_JSA:
  - Type: bool
  - Entity: benunit
  - Description: Whether this family is imputed to claim JSA based on survey response and take-up rates
  - Mean: 0.24464208619915548
  - Median: 0.0
  - Stddev: 0.43153267411936014
  - Non-zero count: 8621124.0


- would_claim_JSA:
  - Type: bool
  - Entity: benunit
  - Description: Would claim JSA
  - Mean: 0.6050246622123397
  - Median: 1.0
  - Stddev: 0.488561424517495
  - Non-zero count: 21320913.0


- CTC_child_element:
  - Type: float
  - Entity: benunit
  - Description: CTC entitlement from child elements
  - Mean: 400.33768294898414
  - Median: 0.0
  - Stddev: 1564.773193359375
  - Non-zero count: 2582172.0


- CTC_disabled_child_element:
  - Type: float
  - Entity: benunit
  - Description: CTC entitlement from disabled child elements
  - Mean: 0.42813693130897496
  - Median: 0.0
  - Stddev: 49.74927520751953
  - Non-zero count: 4497.0


- CTC_family_element:
  - Type: float
  - Entity: benunit
  - Description: CTC entitlement in the Family Element
  - Mean: 39.93456422013532
  - Median: 0.0
  - Stddev: 147.22927856445312
  - Non-zero count: 2582172.0


- CTC_maximum_rate:
  - Type: float
  - Entity: benunit
  - Description: The maximum rate of CTC
  - Mean: 440.80736331724563
  - Median: 0.0
  - Stddev: 1710.2464599609375
  - Non-zero count: 2582172.0


- CTC_severely_disabled_child_element:
  - Type: float
  - Entity: benunit
  - Description: CTC entitlement from severely disabled child elements
  - Mean: 0.10697921681719463
  - Median: 0.0
  - Stddev: 12.755636215209961
  - Non-zero count: 2772.0


- WTC_basic_element:
  - Type: float
  - Entity: benunit
  - Description: WTC entitlement from the basic element
  - Mean: 135.69128173526354
  - Median: 0.0
  - Stddev: 516.4009399414062
  - Non-zero count: 2439656.0


- WTC_childcare_element:
  - Type: float
  - Entity: benunit
  - Description: WTC entitlement from the childcare element
  - Mean: 37.522627631768906
  - Median: 0.0
  - Stddev: 460.3105163574219
  - Non-zero count: 499687.0


- WTC_couple_element:
  - Type: float
  - Entity: benunit
  - Description: WTC entitlement from the couple element
  - Mean: 115.20065101498189
  - Median: 0.0
  - Stddev: 481.6431579589844
  - Non-zero count: 2019722.0


- WTC_disabled_element:
  - Type: float
  - Entity: benunit
  - Description: WTC entitlement from the disabled element
  - Mean: 6.848089863995032
  - Median: 0.0
  - Stddev: 145.26614379882812
  - Non-zero count: 76248.0


- WTC_lone_parent_element:
  - Type: float
  - Entity: benunit
  - Description: WTC entitlement from the lone parent element
  - Mean: 20.578409739776188
  - Median: 0.0
  - Stddev: 210.48147583007812
  - Non-zero count: 360785.0


- WTC_maximum_rate:
  - Type: float
  - Entity: benunit
  - Description: The maximum rate of WTC
  - Mean: 365.46024023474325
  - Median: 0.0
  - Stddev: 1467.5064697265625
  - Non-zero count: 2439656.0


- WTC_severely_disabled_element:
  - Type: float
  - Entity: benunit
  - Description: WTC entitlement from the severely disabled element
  - Mean: 2.4274634303508806
  - Median: 0.0
  - Stddev: 62.65589141845703
  - Non-zero count: 62669.0


- WTC_worker_element:
  - Type: float
  - Entity: benunit
  - Description: WTC entitlement from the worker element
  - Mean: 47.191717805425476
  - Median: 0.0
  - Stddev: 195.90939331054688
  - Non-zero count: 2053116.0


- child_tax_credit:
  - Type: float
  - Entity: benunit
  - Description: Child Tax Credit
  - Mean: 164.8701042178578
  - Median: 0.0
  - Stddev: 1093.0458984375
  - Non-zero count: 1127007.0


- child_tax_credit_reported:
  - Type: float
  - Entity: person
  - Description: Working Tax Credit
  - Mean: 156.19498221146435
  - Median: 0.0
  - Stddev: 1165.629638671875
  - Non-zero count: 1870822.0


- claims_CTC:
  - Type: bool
  - Entity: benunit
  - Description: Whether this family is imputed to claim Child Tax Credit, based on survey response and take-up rates
  - Mean: 0.3370239203226857
  - Median: 0.0
  - Stddev: 0.4735074490310292
  - Non-zero count: 11876636.0


- claims_WTC:
  - Type: bool
  - Entity: benunit
  - Description: Whether this family is imputed to claim Working Tax Credit, based on survey response and take-up rates
  - Mean: 0.2652464084441935
  - Median: 0.0
  - Stddev: 0.44270948572407465
  - Non-zero count: 9347215.0


- is_CTC_child_limit_exempt:
  - Type: bool
  - Entity: person
  - Description: Whether the person was born before 2017 and therefore exempt from the two-child limit for Child Tax Credit
  - Mean: 0.9526647147028426
  - Median: 1.0
  - Stddev: 0.21352091679788665
  - Non-zero count: 62508718.0


- is_CTC_eligible:
  - Type: bool
  - Entity: benunit
  - Description: Whether the family is eligible for CTC
  - Mean: 0.21667425941994695
  - Median: 0.0
  - Stddev: 0.42127591518038066
  - Non-zero count: 7635545.0


- is_WTC_eligible:
  - Type: bool
  - Entity: benunit
  - Description: Whether the family is eligible for WTC
  - Mean: 0.2558223610150154
  - Median: 0.0
  - Stddev: 0.4449912000516362
  - Non-zero count: 9015114.0


- is_child_for_CTC:
  - Type: bool
  - Entity: person
  - Description: Whether this person is a child conferring CTC eligibility
  - Mean: 0.20144518436779715
  - Median: 0.0
  - Stddev: 0.4102249556804412
  - Non-zero count: 13217746.0


- tax_credits:
  - Type: float
  - Entity: benunit
  - Description: Value of the Tax Credits (benefits) for this family
  - Mean: 203.1898881879723
  - Median: 0.0
  - Stddev: 1313.833984375
  - Non-zero count: 1276910.0


- tax_credits_applicable_income:
  - Type: float
  - Entity: benunit
  - Description: Applicable income for Tax Credits
  - Mean: 32806.44582034954
  - Median: 22454.399570745074
  - Stddev: 38275.953125
  - Non-zero count: 30528863.0


- tax_credits_reduction:
  - Type: float
  - Entity: benunit
  - Description: Reduction in Tax Credits from means-tested income
  - Mean: 11187.699421869554
  - Median: 6512.894196254548
  - Stddev: 15361.18359375
  - Non-zero count: 28460491.0


- working_tax_credit:
  - Type: float
  - Entity: benunit
  - Description: Working Tax Credit
  - Mean: 38.31978557011825
  - Median: 0.0
  - Stddev: 412.5762023925781
  - Non-zero count: 450861.0


- working_tax_credit_reported:
  - Type: float
  - Entity: person
  - Description: Working Tax Credit
  - Mean: 36.78026423756542
  - Median: 0.0
  - Stddev: 440.1995849609375
  - Non-zero count: 1035774.0


- would_claim_CTC:
  - Type: bool
  - Entity: benunit
  - Description: Would claim CTC
  - Mean: 0.8275463821500169
  - Median: 1.0
  - Stddev: 0.3766961581383781
  - Non-zero count: 29162521.0


- would_claim_WTC:
  - Type: bool
  - Entity: benunit
  - Description: Would claim WTC
  - Mean: 0.2652464084441935
  - Median: 0.0
  - Stddev: 0.44270948572407465
  - Non-zero count: 9347215.0


- claims_IS:
  - Type: bool
  - Entity: benunit
  - Description: Whether this family is imputed to claim Income Support
  - Mean: 0.36699408866273764
  - Median: 0.0
  - Stddev: 0.48240720200675785
  - Non-zero count: 12932777.0


- income_support:
  - Type: float
  - Entity: benunit
  - Description: Income Support
  - Mean: 18.385365628811684
  - Median: 0.0
  - Stddev: 386.3847351074219
  - Non-zero count: 132799.0


- income_support_applicable_amount:
  - Type: float
  - Entity: benunit
  - Description: Applicable amount of Income Support
  - Mean: 45.203139033062
  - Median: 0.0
  - Stddev: 696.571533203125
  - Non-zero count: 204789.0


- income_support_applicable_income:
  - Type: float
  - Entity: benunit
  - Description: Relevant income for Income Support means test
  - Mean: 25252.396618505514
  - Median: 19223.526873420265
  - Stddev: 24435.818359375
  - Non-zero count: 30587483.0


- income_support_eligible:
  - Type: bool
  - Entity: benunit
  - Description: Whether eligible for Income Support
  - Mean: 0.01665565542449204
  - Median: 0.0
  - Stddev: 0.1365390392399348
  - Non-zero count: 586941.0


- income_support_reported:
  - Type: float
  - Entity: person
  - Description: Income Support (reported amount)
  - Mean: 21.068868578640878
  - Median: 0.0
  - Stddev: 382.022216796875
  - Non-zero count: 378065.0


- would_claim_IS:
  - Type: bool
  - Entity: benunit
  - Description: Would claim IS
  - Mean: 0.8981577390663076
  - Median: 1.0
  - Stddev: 0.3025527785847836
  - Non-zero count: 31650847.0


- UC_carer_element:
  - Type: float
  - Entity: benunit
  - Description: UC carer element
  - Mean: 35.89246407261461
  - Median: 0.0
  - Stddev: 280.04815673828125
  - Non-zero count: 657949.0


- UC_child_element:
  - Type: float
  - Entity: benunit
  - Description: UC child element
  - Mean: 1176.222240790418
  - Median: 0.0
  - Stddev: 2428.84228515625
  - Non-zero count: 8311716.0


- UC_childcare_element:
  - Type: float
  - Entity: benunit
  - Description: UC childcare element
  - Mean: 151.8639020962045
  - Median: 0.0
  - Stddev: 1029.91259765625
  - Non-zero count: 1541416.0


- UC_childcare_work_condition:
  - Type: bool
  - Entity: benunit
  - Description: Meets childcare work condition
  - Mean: 0.5404914712485693
  - Median: 1.0
  - Stddev: 0.49992847516301825
  - Non-zero count: 19046780.0


- UC_claimant_type:
  - Type: Categorical
  - Entity: benunit
  - Description: UC claimant type


- UC_disability_element:
  - Type: float
  - Entity: benunit
  - Description: UC disability element
  - Mean: 10.397574224144044
  - Median: 0.0
  - Stddev: 41.27475357055664
  - Non-zero count: 2723708.0


- UC_earned_income:
  - Type: float
  - Entity: benunit
  - Description: UC earned income (after disregards)
  - Mean: 20455.55957518932
  - Median: 9869.76175638628
  - Stddev: 34223.30078125
  - Non-zero count: 21417959.0


- UC_housing_costs_element:
  - Type: float
  - Entity: benunit
  - Description: UC housing costs element
  - Mean: 1358.1754225015034
  - Median: 0.0
  - Stddev: 2603.545654296875
  - Non-zero count: 10603939.0


- UC_income_reduction:
  - Type: float
  - Entity: benunit
  - Description: Reduction from income for Universal Credit
  - Mean: 18460.017684342252
  - Median: 13248.0085360456
  - Stddev: 22516.916015625
  - Non-zero count: 29978581.0


- UC_individual_child_element:
  - Type: float
  - Entity: person
  - Description: UC child element for the child
  - Mean: 631.7155903298024
  - Median: 0.0
  - Stddev: 1265.4931640625
  - Non-zero count: 13482081.0


- UC_individual_disabled_element:
  - Type: float
  - Entity: person
  - Description: Disabled element of UC
  - Mean: 5.467350783313924
  - Median: 0.0
  - Stddev: 28.060922622680664
  - Non-zero count: 2844644.0


- UC_individual_non_dep_deduction:
  - Type: float
  - Entity: person
  - Description: Non-dependent deduction (individual)
  - Mean: 61.61881656858268
  - Median: 0.0
  - Stddev: 203.72137451171875
  - Non-zero count: 4460804.0


- UC_individual_severely_disabled_element:
  - Type: float
  - Entity: person
  - Description: Severely disabled element of UC
  - Mean: 0.11689130860564846
  - Median: 0.0
  - Stddev: 5.712952136993408
  - Non-zero count: 28837.0


- UC_maximum_amount:
  - Type: float
  - Entity: benunit
  - Description: Maximum UC amount
  - Mean: 6586.488684095139
  - Median: 4742.39990234375
  - Stddev: 4440.5029296875
  - Non-zero count: 35185075.0


- UC_non_dep_deductions:
  - Type: float
  - Entity: benunit
  - Description: Non-dependent deductions
  - Mean: 182.48354570781612
  - Median: 0.0
  - Stddev: 425.0693054199219
  - Non-zero count: 5255745.0


- UC_standard_allowance:
  - Type: float
  - Entity: benunit
  - Description: UC Standard Allowance
  - Mean: 3853.937000416633
  - Median: 3021.239990234375
  - Stddev: 860.4164428710938
  - Non-zero count: 35239742.0


- UC_unearned_income:
  - Type: float
  - Entity: benunit
  - Description: UC unearned income
  - Mean: 5573.015208858396
  - Median: 0.0
  - Stddev: 13082.95703125
  - Non-zero count: 10664413.0


- claims_UC:
  - Type: bool
  - Entity: benunit
  - Description: Family claims UC
  - Mean: 0.24929234725952307
  - Median: 0.0
  - Stddev: 0.4319181941195248
  - Non-zero count: 8784998.0


- is_child_born_before_child_limit:
  - Type: bool
  - Entity: person
  - Description: Born before child limit (exempt)
  - Mean: 0.15573031576933696
  - Median: 0.0
  - Stddev: 0.3709802969446774
  - Non-zero count: 10218183.0


- num_UC_eligible_children:
  - Type: int
  - Entity: benunit
  - Description: Eligible children
  - Mean: 0.3812855099790458
  - Median: 0.0
  - Stddev: 0.7939189326780967
  - Non-zero count: 8311716.0


- universal_credit:
  - Type: float
  - Entity: benunit
  - Description: Universal Credit
  - Mean: 687.4821255449992
  - Median: 0.0
  - Stddev: 2566.418212890625
  - Non-zero count: 3680392.0


- universal_credit_reported:
  - Type: float
  - Entity: person
  - Description: Universal Credit
  - Mean: 177.78277315216826
  - Median: 0.0
  - Stddev: 1446.98681640625
  - Non-zero count: 1346214.0


- ESA_contrib:
  - Type: float
  - Entity: person
  - Description: ESA (contribution-based)
  - Mean: 27.928893974743655
  - Median: 0.0
  - Stddev: 513.2649536132812
  - Non-zero count: 291147.0


- ESA_contrib_reported:
  - Type: float
  - Entity: person
  - Description: Employment and Support Allowance (contribution-based) (reported)
  - Mean: 27.928893974743655
  - Median: 0.0
  - Stddev: 513.2649536132812
  - Non-zero count: 291147.0


- SDA:
  - Type: float
  - Entity: person
  - Description: Severe Disablement Allowance
  - Mean: 0.9910744642138852
  - Median: 0.0
  - Stddev: 77.07752990722656
  - Non-zero count: 15110.0


- SDA_reported:
  - Type: float
  - Entity: person
  - Description: Severe Disablement Allowance (reported)
  - Mean: 0.9910744642138852
  - Median: 0.0
  - Stddev: 77.07752990722656
  - Non-zero count: 15110.0


- AA:
  - Type: float
  - Entity: person
  - Description: Attendance Allowance
  - Mean: 48.97309835560918
  - Median: 0.0
  - Stddev: 485.9969177246094
  - Non-zero count: 814195.0


- AA_reported:
  - Type: float
  - Entity: person
  - Description: Attendance Allowance (reported)
  - Mean: 48.97309835560918
  - Median: 0.0
  - Stddev: 485.9969177246094
  - Non-zero count: 814195.0


- DLA:
  - Type: float
  - Entity: person
  - Description: Disability Living Allowance
  - Mean: 82.18857186285
  - Median: 0.0
  - Stddev: 770.2195434570312
  - Non-zero count: 1150007.0


- DLA_M:
  - Type: float
  - Entity: person
  - Description: Disability Living Allowance (mobility component)
  - Mean: 32.77108598895431
  - Median: 0.0
  - Stddev: 350.33184814453125
  - Non-zero count: 828914.0


- DLA_M_reported:
  - Type: float
  - Entity: person
  - Description: Disability Living Allowance (mobility component) (reported)
  - Mean: 32.77108598895431
  - Median: 0.0
  - Stddev: 350.33184814453125
  - Non-zero count: 828914.0


- DLA_SC:
  - Type: float
  - Entity: person
  - Description: Disability Living Allowance (self-care)
  - Mean: 49.417484403629295
  - Median: 0.0
  - Stddev: 490.4149169921875
  - Non-zero count: 1013710.0


- DLA_SC_reported:
  - Type: float
  - Entity: person
  - Description: Disability Living Allowance (self-care) (reported)
  - Mean: 49.417484403629295
  - Median: 0.0
  - Stddev: 490.4149169921875
  - Non-zero count: 1013710.0


- JSA_contrib:
  - Type: float
  - Entity: person
  - Description: JSA (contribution-based)
  - Mean: 1.6389978477662854
  - Median: 0.0
  - Stddev: 79.90789031982422
  - Non-zero count: 28861.0


- JSA_contrib_reported:
  - Type: float
  - Entity: person
  - Description: Job Seeker's Allowance (contribution-based) (reported)
  - Mean: 1.6389978477662854
  - Median: 0.0
  - Stddev: 79.90789031982422
  - Non-zero count: 28861.0


- maternity_allowance_reported:
  - Type: float
  - Entity: person
  - Description: Maternity allowance
  - Mean: 1.4504206775837039
  - Median: 0.0
  - Stddev: 106.53939819335938
  - Non-zero count: 13961.0


- winter_fuel_allowance_reported:
  - Type: float
  - Entity: person
  - Description: Winter fuel allowance
  - Mean: 29.562892736501162
  - Median: 0.0
  - Stddev: 74.6936264038086
  - Non-zero count: 11479871.0


- student_loans:
  - Type: float
  - Entity: person
  - Description: Student loans
  - Mean: 224.5202469864788
  - Median: -1.0
  - Stddev: 1334.06884765625
  - Non-zero count: 1440269.0


- student_payments:
  - Type: float
  - Entity: person
  - Description: Student payments
  - Mean: -48.19349524904742
  - Median: -106.0
  - Stddev: 710.353271484375
  - Non-zero count: 569093.0


- PIP:
  - Type: float
  - Entity: person
  - Description: Personal Independence Payment
  - Mean: 135.07113453478942
  - Median: 0.0
  - Stddev: 952.6376342773438
  - Non-zero count: 1701262.0


- PIP_DL:
  - Type: float
  - Entity: person
  - Description: Personal Independence Payment (Daily Living)
  - Mean: 91.787446784872
  - Median: 0.0
  - Stddev: 633.8505859375
  - Non-zero count: 1616764.0


- PIP_DL_reported:
  - Type: float
  - Entity: person
  - Description: Personal Independence Payment (Daily Living) (reported)
  - Mean: 91.787446784872
  - Median: 0.0
  - Stddev: 633.8505859375
  - Non-zero count: 1616764.0


- PIP_M:
  - Type: float
  - Entity: person
  - Description: Personal Independence Payment (Mobility)
  - Mean: 43.283684197490835
  - Median: 0.0
  - Stddev: 373.4668884277344
  - Non-zero count: 1209793.0


- PIP_M_reported:
  - Type: float
  - Entity: person
  - Description: Personal Independence Payment (Mobility) (reported)
  - Mean: 43.283684197490835
  - Median: 0.0
  - Stddev: 373.4668884277344
  - Non-zero count: 1209793.0


- carers_allowance:
  - Type: float
  - Entity: person
  - Description: Carer's Allowance
  - Mean: 34.61541230404279
  - Median: 0.0
  - Stddev: 366.1167297363281
  - Non-zero count: 662945.0


- carers_allowance_reported:
  - Type: float
  - Entity: person
  - Description: Carer's Allowance (reported)
  - Mean: 34.61541230404279
  - Median: 0.0
  - Stddev: 366.1167297363281
  - Non-zero count: 662945.0


- BSP:
  - Type: float
  - Entity: person
  - Description: Bereavement Support Payment
  - Mean: 13.54695832568416
  - Median: 0.0
  - Stddev: 383.7933654785156
  - Non-zero count: 170501.0


- BSP_reported:
  - Type: float
  - Entity: person
  - Description: Bereavement Support Payment (reported)
  - Mean: 13.54695832568416
  - Median: 0.0
  - Stddev: 383.7933654785156
  - Non-zero count: 170501.0


- is_SP_age:
  - Type: bool
  - Entity: person
  - Description: Whether the person is State Pension Age
  - Mean: 0.16136573802990567
  - Median: 0.0
  - Stddev: 0.39623673527502545
  - Non-zero count: 10587949.0


- state_pension:
  - Type: float
  - Entity: person
  - Description: Income from the State Pension
  - Mean: 1344.9403607065296
  - Median: 0.0
  - Stddev: 3347.569091796875
  - Non-zero count: 11302238.0


- state_pension_age:
  - Type: float
  - Entity: person
  - Description: State Pension age for this person
  - Mean: 66.0
  - Median: 66.0
  - Stddev: 0.0
  - Non-zero count: 65614604.0


- state_pension_reported:
  - Type: float
  - Entity: person
  - Description: Reported income from the State Pension
  - Mean: 1344.9403607065296
  - Median: 0.0
  - Stddev: 3347.569091796875
  - Non-zero count: 11302238.0


- incapacity_benefit:
  - Type: float
  - Entity: person
  - Description: Incapacity Benefit
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- incapacity_benefit_reported:
  - Type: float
  - Entity: person
  - Description: Incapacity Benefit (reported)
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- IIDB:
  - Type: float
  - Entity: person
  - Description: Industrial Injuries Disablement Benefit
  - Mean: 7.557060126518677
  - Median: 0.0
  - Stddev: 206.86599731445312
  - Non-zero count: 152041.0


- IIDB_reported:
  - Type: float
  - Entity: person
  - Description: Industrial Injuries Disablement Benefit (reported)
  - Mean: 7.557060126518677
  - Median: 0.0
  - Stddev: 206.86599731445312
  - Non-zero count: 152041.0


- AFCS:
  - Type: float
  - Entity: person
  - Description: Armed Forces Compensation Scheme
  - Mean: 48.97309835560918
  - Median: 0.0
  - Stddev: 485.9969177246094
  - Non-zero count: 814195.0


- AFCS_reported:
  - Type: float
  - Entity: person
  - Description: Armed Forces Compensation Scheme (reported)
  - Mean: 4.27192939685241
  - Median: 0.0
  - Stddev: 192.32044982910156
  - Non-zero count: 58179.0


- tax:
  - Type: float
  - Entity: person
  - Description: Total tax
  - Mean: 3515.300399536169
  - Median: 20.860000610351562
  - Stddev: 9048.91796875
  - Non-zero count: 32947495.0


- tax_modelling:
  - Type: float
  - Entity: person
  - Description: Difference between reported and imputed tax liabilities
  - Mean: 3515.300399536169
  - Median: 20.860000610351562
  - Stddev: 9048.91796875
  - Non-zero count: 32947495.0


- tax_reported:
  - Type: float
  - Entity: person
  - Description: Reported tax paid
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- NI_class_4:
  - Type: float
  - Entity: person
  - Description: Class 4 Contributions for National Insurance for the year
  - Mean: 80.15496955534952
  - Median: 0.0
  - Stddev: 484.1212463378906
  - Non-zero count: 3074849.0


- employee_NI:
  - Type: float
  - Entity: person
  - Description: Employee-side NI
  - Mean: 930.9732495252766
  - Median: 0.0
  - Stddev: 1557.903076171875
  - Non-zero count: 24235643.0


- national_insurance:
  - Type: float
  - Entity: person
  - Description: National Insurance
  - Mean: 1019.0496282941336
  - Median: 0.0
  - Stddev: 1601.7862548828125
  - Non-zero count: 27460700.0


- self_employed_NI:
  - Type: float
  - Entity: person
  - Description: Self-employed NI
  - Mean: 88.07637706640077
  - Median: 0.0
  - Stddev: 507.1832580566406
  - Non-zero count: 3331795.0


- NI_class_2:
  - Type: float
  - Entity: person
  - Description: Class 2 Contributions for National Insurance for the year
  - Mean: 7.921407557378537
  - Median: 0.0
  - Stddev: 33.1730842590332
  - Non-zero count: 3331795.0


- weekly_NI_class_2:
  - Type: float
  - Entity: person
  - Description: Class 2 Contributions for National Insurance
  - Mean: 7.921407557378537
  - Median: 0.0
  - Stddev: 33.1730842590332
  - Non-zero count: 3331795.0


- NI_exempt:
  - Type: bool
  - Entity: person
  - Description: Whether is exempt from National Insurance
  - Mean: 0.3518808099489559
  - Median: 0.0
  - Stddev: 0.48921027982484017
  - Non-zero count: 23088520.0


- employee_NI_class_1:
  - Type: float
  - Entity: person
  - Description: Employee Class 1 Contributions for National Insurance
  - Mean: 930.9732495252766
  - Median: 0.0
  - Stddev: 1557.903076171875
  - Non-zero count: 24235643.0


- employer_NI:
  - Type: float
  - Entity: person
  - Description: Employer contributions to National Insurance
  - Mean: 1288.81406248566
  - Median: 0.0
  - Stddev: 2806.6474609375
  - Non-zero count: 24235643.0


- employer_NI_class_1:
  - Type: float
  - Entity: person
  - Description: Employer Class 1 Contributions for National Insurance
  - Mean: 1288.81406248566
  - Median: 0.0
  - Stddev: 2806.6474609375
  - Non-zero count: 24235643.0


- total_NI:
  - Type: float
  - Entity: person
  - Description: NI (total)
  - Mean: 2307.8636495498295
  - Median: 0.0
  - Stddev: 4258.63818359375
  - Non-zero count: 27460700.0


- dividend_income:
  - Type: float
  - Entity: person
  - Description: Income from dividends
  - Mean: 138.35076049542894
  - Median: 0.0
  - Stddev: 1876.1806640625
  - Non-zero count: 3646028.0


- employment_income:
  - Type: float
  - Entity: person
  - Description: Employment income
  - Mean: 12768.864975759552
  - Median: 0.0
  - Stddev: 22854.279296875
  - Non-zero count: 26958555.0


- pension_income:
  - Type: float
  - Entity: person
  - Description: Income from pensions
  - Mean: 1611.913567134478
  - Median: 0.0
  - Stddev: 6644.4736328125
  - Non-zero count: 9640303.0


- property_income:
  - Type: float
  - Entity: person
  - Description: Income from rental of property
  - Mean: 96.71131095488771
  - Median: -104.20999908447266
  - Stddev: 2062.39453125
  - Non-zero count: 2034674.0


- savings_interest_income:
  - Type: float
  - Entity: person
  - Description: Income from interest on savings
  - Mean: 97.65798588269206
  - Median: 0.0
  - Stddev: 730.8331909179688
  - Non-zero count: 21886075.0


- self_employment_income:
  - Type: float
  - Entity: person
  - Description: Income from trading profits for owned businesses
  - Mean: 1634.2728057755219
  - Median: 0.0
  - Stddev: 11460.0390625
  - Non-zero count: 4247531.0


- social_security_income:
  - Type: float
  - Entity: person
  - Description: Income from social security for tax purposes
  - Mean: 1409.123664746688
  - Median: 0.0
  - Stddev: 3374.9541015625
  - Non-zero count: 12251021.0


- ISA_interest_income:
  - Type: float
  - Entity: person
  - Description: Amount received in interest from Individual Savings Accounts
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- SMP:
  - Type: float
  - Entity: person
  - Description: SMP
  - Mean: 18.449244772494755
  - Median: 0.0
  - Stddev: 378.63031005859375
  - Non-zero count: 163314.0


- SSP:
  - Type: float
  - Entity: person
  - Description: Statutory Sick Pay
  - Mean: 6.330815817519055
  - Median: 0.0
  - Stddev: 170.3654022216797
  - Non-zero count: 111236.0


- adjusted_net_income:
  - Type: float
  - Entity: person
  - Description: Taxable income after tax reliefs and before allowances
  - Mean: 17175.05215342228
  - Median: 10483.836765972559
  - Stddev: 24704.36328125
  - Non-zero count: 44335496.0


- capital_allowances:
  - Type: float
  - Entity: person
  - Description: Full relief from capital expenditure allowances
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- deficiency_relief:
  - Type: float
  - Entity: person
  - Description: Deficiency relief
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- employment_benefits:
  - Type: float
  - Entity: person
  - Description: Employment benefits
  - Mean: 24.78006059891403
  - Median: 0.0
  - Stddev: 416.91510009765625
  - Non-zero count: 273354.0


- employment_deductions:
  - Type: float
  - Entity: person
  - Description: Deductions from employment income
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- employment_expenses:
  - Type: float
  - Entity: person
  - Description: Cost of expenses necessarily incurred and reimbursed by employment
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- loss_relief:
  - Type: float
  - Entity: person
  - Description: Tax relief from trading losses
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- pension_contributions:
  - Type: float
  - Entity: person
  - Description: Amount contributed to registered pension schemes paid by the individual (not the employer)
  - Mean: 500.68840680059293
  - Median: 0.0
  - Stddev: 1319.6103515625
  - Non-zero count: 19364176.0


- pension_contributions_relief:
  - Type: float
  - Entity: person
  - Description: Reduction in taxable income from pension contributions
  - Mean: 1742.0204047115035
  - Median: 0.0
  - Stddev: 2059.19189453125
  - Non-zero count: 30780947.0


- tax_free_savings_income:
  - Type: float
  - Entity: person
  - Description: Income from savings in tax-free accounts
  - Mean: 41.819862774476064
  - Median: 0.0
  - Stddev: 380.03985595703125
  - Non-zero count: 9243878.0


- taxable_dividend_income:
  - Type: float
  - Entity: person
  - Description: Amount of dividend income that is taxable
  - Mean: 138.35076049542894
  - Median: 0.0
  - Stddev: 1876.1806640625
  - Non-zero count: 3646028.0


- taxable_employment_income:
  - Type: float
  - Entity: person
  - Description: Net taxable earnings
  - Mean: 12306.999291233235
  - Median: 0.0
  - Stddev: 22057.103515625
  - Non-zero count: 32296060.0


- taxable_miscellaneous_income:
  - Type: float
  - Entity: person
  - Description: Amount of miscellaneous income that is taxable
  - Mean: -142.57390163930117
  - Median: -208.0
  - Stddev: 836.8568115234375
  - Non-zero count: 747462.0


- taxable_pension_income:
  - Type: float
  - Entity: person
  - Description: Amount of pension income that is taxable
  - Mean: 1611.913567134478
  - Median: 0.0
  - Stddev: 6644.4736328125
  - Non-zero count: 9640303.0


- taxable_property_income:
  - Type: float
  - Entity: person
  - Description: Amount of property income that is taxable
  - Mean: 172.47905960793858
  - Median: 0.0
  - Stddev: 1964.2425537109375
  - Non-zero count: 1611910.0


- taxable_savings_interest_income:
  - Type: float
  - Entity: person
  - Description: Amount of savings interest which is taxable
  - Mean: 55.83811714514716
  - Median: 0.0
  - Stddev: 566.681640625
  - Non-zero count: 21626465.0


- taxable_self_employment_income:
  - Type: float
  - Entity: person
  - Description: Amount of trading income that is taxable
  - Mean: 1578.8178515412328
  - Median: 0.0
  - Stddev: 11325.3271484375
  - Non-zero count: 4110606.0


- taxable_social_security_income:
  - Type: float
  - Entity: person
  - Description: Amount of social security income that is taxable
  - Mean: 1409.123664746688
  - Median: 0.0
  - Stddev: 3374.9541015625
  - Non-zero count: 12251021.0


- total_income:
  - Type: float
  - Entity: person
  - Description: Taxable income after tax reliefs and before allowances
  - Mean: 17614.32158211031
  - Median: 10577.83984375
  - Stddev: 25461.466796875
  - Non-zero count: 44364730.0


- trading_loss:
  - Type: float
  - Entity: person
  - Description: Loss from trading in the current year.
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- allowances:
  - Type: float
  - Entity: person
  - Description: Allowances applicable to adjusted net income
  - Mean: 12376.708275245806
  - Median: 12500.0
  - Stddev: 1099.981689453125
  - Non-zero count: 65126927.0


- blind_persons_allowance:
  - Type: float
  - Entity: person
  - Description: Blind Person's Allowance for the year (not simulated)
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- charitable_investment_gifts:
  - Type: float
  - Entity: person
  - Description: Gifts of qualifying investment or property to charities
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- covenanted_payments:
  - Type: float
  - Entity: person
  - Description: Covenanted payments to charities
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- dividend_allowance:
  - Type: float
  - Entity: person
  - Description: Dividend allowance for the person
  - Mean: 2000.0
  - Median: 2000.0
  - Stddev: 0.0
  - Non-zero count: 65614604.0


- gift_aid:
  - Type: float
  - Entity: person
  - Description: Expenditure under Gift Aid
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- marriage_allowance:
  - Type: float
  - Entity: person
  - Description: Marriage Allowance for the year (a tax-reducer, rather than an allowance or tax relief)
  - Mean: 84.81293111467204
  - Median: 0.0
  - Stddev: 322.11968994140625
  - Non-zero count: 4635853.0


- married_couples_allowance:
  - Type: float
  - Entity: person
  - Description: Married Couples' allowance for the year
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- married_couples_allowance_deduction:
  - Type: float
  - Entity: person
  - Description: Deduction from Married Couples' allowance for the year
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- other_deductions:
  - Type: float
  - Entity: person
  - Description: All other tax deductions
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- pension_annual_allowance:
  - Type: float
  - Entity: person
  - Description: Annual Allowance for pension contributions
  - Mean: 39946.285496258155
  - Median: 40000.0
  - Stddev: 1160.5516357421875
  - Non-zero count: 65614604.0


- personal_allowance:
  - Type: float
  - Entity: person
  - Description: Personal Allowance for the year
  - Mean: 12376.708275245806
  - Median: 12500.0
  - Stddev: 1099.981689453125
  - Non-zero count: 65126927.0


- property_allowance:
  - Type: float
  - Entity: person
  - Description: Property Allowance for the year
  - Mean: 1000.0
  - Median: 1000.0
  - Stddev: 0.0
  - Non-zero count: 65614604.0


- property_allowance_deduction:
  - Type: float
  - Entity: person
  - Description: Deduction applied by the property allowance
  - Mean: -75.76774897646892
  - Median: -104.20999908447266
  - Stddev: 178.6800994873047
  - Non-zero count: 2034674.0


- savings_allowance:
  - Type: float
  - Entity: person
  - Description: Savings Allowance for the year
  - Mean: 966.1036512542238
  - Median: 1000.0
  - Stddev: 128.7417755126953
  - Non-zero count: 65286908.0


- trading_allowance:
  - Type: float
  - Entity: person
  - Description: Trading Allowance for the year
  - Mean: 1000.0
  - Median: 1000.0
  - Stddev: 0.0
  - Non-zero count: 65614604.0


- trading_allowance_deduction:
  - Type: float
  - Entity: person
  - Description: Deduction applied by the trading allowance
  - Mean: 55.454954087489355
  - Median: 0.0
  - Stddev: 597.5231323242188
  - Non-zero count: 4247531.0


- unused_personal_allowance:
  - Type: float
  - Entity: person
  - Description: Unused personal allowance
  - Mean: 5182.9854420813235
  - Median: 2016.1675528137089
  - Stddev: 5622.470703125
  - Non-zero count: 35450547.0


- CB_HITC:
  - Type: float
  - Entity: person
  - Description: Child Benefit High-Income Tax Charge
  - Mean: 30.34899367291616
  - Median: 0.0
  - Stddev: 218.5277557373047
  - Non-zero count: 1475320.0


- add_rate_earned_income:
  - Type: float
  - Entity: person
  - Description: Earned income (non-savings, non-dividend) at the additional rate
  - Mean: 418.5593964084038
  - Median: 0.0
  - Stddev: 7837.69287109375
  - Non-zero count: 321817.0


- add_rate_earned_income_tax:
  - Type: float
  - Entity: person
  - Description: Income tax on earned income at the additional rate
  - Mean: 188.3517342735483
  - Median: 0.0
  - Stddev: 3528.59619140625
  - Non-zero count: 321817.0


- add_rate_savings_income:
  - Type: float
  - Entity: person
  - Description: Savings income at the higher rate
  - Mean: 0.1771773026245729
  - Median: 0.0
  - Stddev: 18.239421844482422
  - Non-zero count: 7149.0


- basic_rate_earned_income:
  - Type: float
  - Entity: person
  - Description: Earned income (non-savings, non-dividend) at the basic rate
  - Mean: 7372.755323508782
  - Median: 0.0
  - Stddev: 11169.5078125
  - Non-zero count: 29653581.0


- basic_rate_earned_income_tax:
  - Type: float
  - Entity: person
  - Description: Income tax on earned income at the basic rate
  - Mean: 1474.5510867777602
  - Median: 0.0
  - Stddev: 2233.90771484375
  - Non-zero count: 29653581.0


- basic_rate_savings_income:
  - Type: float
  - Entity: person
  - Description: Savings income at the basic rate
  - Mean: 9.586109037257094
  - Median: 0.0
  - Stddev: 401.1287536621094
  - Non-zero count: 96576.0


- basic_rate_savings_income_pre_starter:
  - Type: float
  - Entity: person
  - Description: Savings income which would otherwise be taxed at the basic rate, without the starter rate
  - Mean: 15.735840022153631
  - Median: 0.0
  - Stddev: 415.45245361328125
  - Non-zero count: 534263.0


- dividend_income_tax:
  - Type: float
  - Entity: person
  - Description: Income tax on dividend income
  - Mean: 18.596939313250786
  - Median: 0.0
  - Stddev: 439.9445495605469
  - Non-zero count: 707080.0


- earned_income_tax:
  - Type: float
  - Entity: person
  - Description: Income tax on earned income
  - Mean: 2444.590769267545
  - Median: 0.0
  - Stddev: 7726.14013671875
  - Non-zero count: 29653581.0


- earned_taxable_income:
  - Type: float
  - Entity: person
  - Description: Non-savings, non-dividend income for Income Tax
  - Mean: 9738.077714953833
  - Median: 0.0
  - Stddev: 22410.107421875
  - Non-zero count: 29653581.0


- higher_rate_earned_income:
  - Type: float
  - Entity: person
  - Description: Earned income (non-savings, non-dividend) at the higher rate
  - Mean: 1946.762998018873
  - Median: 0.0
  - Stddev: 10565.87890625
  - Non-zero count: 3979818.0


- higher_rate_earned_income_tax:
  - Type: float
  - Entity: person
  - Description: Income tax on earned income at the higher rate
  - Mean: 778.7052113078482
  - Median: 0.0
  - Stddev: 4225.42822265625
  - Non-zero count: 3979818.0


- higher_rate_savings_income:
  - Type: float
  - Entity: person
  - Description: Savings income at the higher rate
  - Mean: 1.7929418913562307
  - Median: 0.0
  - Stddev: 195.0398712158203
  - Non-zero count: 21036.0


- income_tax:
  - Type: float
  - Entity: person
  - Description: Income Tax
  - Mean: 2496.250826174807
  - Median: 0.0
  - Stddev: 7902.8212890625
  - Non-zero count: 29911512.0


- income_tax_pre_charges:
  - Type: float
  - Entity: person
  - Description: Income Tax before any tax charges
  - Mean: 2465.901834594413
  - Median: 0.0
  - Stddev: 7802.60888671875
  - Non-zero count: 29911512.0


- is_higher_earner:
  - Type: bool
  - Entity: person
  - Description: Whether this person is the highest earner in a family
  - Mean: 0.5370716250912678
  - Median: 1.0
  - Stddev: 0.4993882658360249
  - Non-zero count: 35239742.0


- pays_scottish_income_tax:
  - Type: float
  - Entity: person
  - Description: Whether the individual pays Scottish Income Tax rates
  - Mean: 0.04722294750113862
  - Median: 0.0
  - Stddev: 0.19097428023815155
  - Non-zero count: 3098515.0


- savings_income_tax:
  - Type: float
  - Entity: person
  - Description: Income tax on savings income
  - Mean: 2.714129219007175
  - Median: 0.0
  - Stddev: 121.51437377929688
  - Non-zero count: 113427.0


- savings_starter_rate_income:
  - Type: float
  - Entity: person
  - Description: Savings income which is tax-free under the starter rate
  - Mean: 4989.022103151227
  - Median: 5000.0
  - Stddev: 188.06610107421875
  - Non-zero count: 65564394.0


- tax_band:
  - Type: Categorical
  - Entity: person
  - Description: Tax band of the individual


- taxed_dividend_income:
  - Type: float
  - Entity: person
  - Description: Dividend income which is taxed
  - Mean: 101.67540050314555
  - Median: 0.0
  - Stddev: 1744.8206787109375
  - Non-zero count: 707080.0


- taxed_income:
  - Type: float
  - Entity: person
  - Description: Income which is taxed
  - Mean: 9851.30934421245
  - Median: 0.0
  - Stddev: 22641.125
  - Non-zero count: 29911512.0


- taxed_savings_income:
  - Type: float
  - Entity: person
  - Description: Savings income which advances the person's income tax schedule
  - Mean: 11.5562286509305
  - Median: 0.0
  - Stddev: 475.9393615722656
  - Non-zero count: 113427.0


- in_deep_poverty_ahc:
  - Type: bool
  - Entity: household
  - Description: Whether the household is in deep absolute poverty (below half the poverty line), after housing costs
  - Mean: 0.07751704434489656
  - Median: 0.0
  - Stddev: 0.2650916156112733
  - Non-zero count: 2172323.0


- in_deep_poverty_bhc:
  - Type: bool
  - Entity: household
  - Description: Whether the household is in deep absolute poverty (below half the poverty line), before housing costs
  - Mean: 0.038780021746506924
  - Median: 0.0
  - Stddev: 0.19370035619293877
  - Non-zero count: 1086764.0


- in_poverty_ahc:
  - Type: bool
  - Entity: household
  - Description: Whether the household is in absolute poverty, after housing costs
  - Mean: 0.16925852804245647
  - Median: 0.0
  - Stddev: 0.3810089128601301
  - Non-zero count: 4743269.0


- in_poverty_bhc:
  - Type: bool
  - Entity: household
  - Description: Whether the household is in absolute poverty, before housing costs
  - Mean: 0.1531571134275777
  - Median: 0.0
  - Stddev: 0.37298232527732644
  - Non-zero count: 4292046.0


- poverty_gap_ahc:
  - Type: float
  - Entity: household
  - Description: Positive financial gap between net household income and the poverty line, after housing costs
  - Mean: 1050.8501220035696
  - Median: 0.0
  - Stddev: 3185.76611328125
  - Non-zero count: 4743269.0


- poverty_gap_bhc:
  - Type: float
  - Entity: household
  - Description: Positive financial gap between net household income and the poverty line
  - Mean: 743.5826083659913
  - Median: 0.0
  - Stddev: 2512.77392578125
  - Non-zero count: 4292046.0


- poverty_line_ahc:
  - Type: float
  - Entity: household
  - Description: The poverty line for the household, after housing costs
  - Mean: 10589.431277428384
  - Median: 8143.2001953125
  - Stddev: 4630.7236328125
  - Non-zero count: 28023811.0


- poverty_line_bhc:
  - Type: float
  - Entity: household
  - Description: The poverty line for the household, before housing costs
  - Mean: 13535.524783725226
  - Median: 11009.4404296875
  - Stddev: 4715.75830078125
  - Non-zero count: 28023811.0


- age:
  - Type: float
  - Entity: person
  - Description: The age of the person in years
  - Mean: 39.26108829369754
  - Median: 39.0
  - Stddev: 23.648860931396484
  - Non-zero count: 64895858.0


- age_18_64:
  - Type: bool
  - Entity: person
  - Description: Whether the person is age 18 to 64
  - Mean: 0.6124335064187845
  - Median: 1.0
  - Stddev: 0.49555872207518314
  - Non-zero count: 40184582.0


- age_over_64:
  - Type: bool
  - Entity: person
  - Description: Whether the person is over age 64
  - Mean: 0.17128235659244395
  - Median: 0.0
  - Stddev: 0.40539378928130615
  - Non-zero count: 11238624.0


- age_under_18:
  - Type: bool
  - Entity: person
  - Description: Whether the person is under age 18
  - Mean: 0.21628413698877158
  - Median: 0.0
  - Stddev: 0.4183352569428601
  - Non-zero count: 14191398.0


- birth_year:
  - Type: float
  - Entity: person
  - Description: The birth year of the person
  - Mean: 1981.7389117063024
  - Median: 1982.0
  - Stddev: 23.648834228515625
  - Non-zero count: 65614604.0


- child_index:
  - Type: int
  - Entity: person
  - Description: Child reference number
  - Mean: 78.70471739797439
  - Median: 100.0
  - Stddev: 41.17906109957911
  - Non-zero count: 65614604.0


- current_education:
  - Type: Categorical
  - Entity: person
  - Description: Current education


- gender:
  - Type: Categorical
  - Entity: person
  - Description: Gender of the person


- highest_education:
  - Type: Categorical
  - Entity: person
  - Description: Highest status education completed


- in_FE:
  - Type: bool
  - Entity: person
  - Description: Whether this person is in Further Education
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- in_HE:
  - Type: bool
  - Entity: person
  - Description: In higher education
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- in_social_housing:
  - Type: bool
  - Entity: person
  - Description: Whether this person lives in social housing
  - Mean: 0.1627882567118747
  - Median: 0.0
  - Stddev: 0.37780549089136584
  - Non-zero count: 10681287.0


- is_WA_adult:
  - Type: bool
  - Entity: person
  - Description: Whether is a working-age adult
  - Mean: 0.6223501249813228
  - Median: 1.0
  - Stddev: 0.4937540588260953
  - Non-zero count: 40835257.0


- is_adult:
  - Type: bool
  - Entity: person
  - Description: Whether this person is an adult
  - Mean: 0.7837158630112284
  - Median: 1.0
  - Stddev: 0.4183352569428601
  - Non-zero count: 51423206.0


- is_benunit_eldest_child:
  - Type: bool
  - Entity: person
  - Description: Eldest child in the benefit unit
  - Mean: 0.5739144596529151
  - Median: 1.0
  - Stddev: 0.49623138123827143
  - Non-zero count: 37657170.0


- is_benunit_head:
  - Type: bool
  - Entity: person
  - Description: Whether this person is the head-of-family
  - Mean: 0.5370716250912678
  - Median: 1.0
  - Stddev: 0.4993882658360249
  - Non-zero count: 35239742.0


- is_child:
  - Type: bool
  - Entity: person
  - Description: Is a child
  - Mean: 0.21628413698877158
  - Median: 0.0
  - Stddev: 0.4183352569428601
  - Non-zero count: 14191398.0


- is_female:
  - Type: bool
  - Entity: person
  - Description: Whether the person is female
  - Mean: 0.5063038405291602
  - Median: 1.0
  - Stddev: 0.4996619537061989
  - Non-zero count: 33220926.0


- is_household_head:
  - Type: bool
  - Entity: person
  - Description: Whether this person is the head-of-household
  - Mean: 0.4270971596506168
  - Median: 0.0
  - Stddev: 0.49680386165484386
  - Non-zero count: 28023811.0


- is_male:
  - Type: bool
  - Entity: person
  - Description: Whether the person is male
  - Mean: 0.4936961594708398
  - Median: 0.0
  - Stddev: 0.4996619537061989
  - Non-zero count: 32393678.0


- is_older_child:
  - Type: bool
  - Entity: person
  - Description: Whether the person is over 14 but under 18
  - Mean: 0.04854085532543944
  - Median: 0.0
  - Stddev: 0.21590012114739232
  - Non-zero count: 3184989.0


- is_young_child:
  - Type: bool
  - Entity: person
  - Description: Whether the person is under 14
  - Mean: 0.16774328166333213
  - Median: 0.0
  - Stddev: 0.38177901330435976
  - Non-zero count: 11006409.0


- marital_status:
  - Type: Categorical
  - Entity: person
  - Description: Marital status


- over_16:
  - Type: bool
  - Entity: person
  - Description: Whether the person is over 16
  - Mean: 0.8094849280809497
  - Median: 1.0
  - Stddev: 0.4012150589689833
  - Non-zero count: 53114033.0


- people:
  - Type: float
  - Entity: person
  - Description: Variable holding people
  - Mean: 1.0
  - Median: 1.0
  - Stddev: 0.0
  - Non-zero count: 65614604.0


- person_id:
  - Type: int
  - Entity: person
  - Description: ID for the person
  - Mean: 959656.6117144591
  - Median: 959552.8093983312
  - Stddev: 554308.7927831486
  - Non-zero count: 65614604.0


- person_weight:
  - Type: float
  - Entity: person
  - Description: Weight factor for the person
  - Mean: 2001.5659137712696
  - Median: 1699.0
  - Stddev: 858.664306640625
  - Non-zero count: 65614604.0


- benunit_id:
  - Type: int
  - Entity: benunit
  - Description: ID for the family
  - Mean: 959451.5537894687
  - Median: 961134.1430700447
  - Stddev: 553578.6907779488
  - Non-zero count: 35239742.0


- benunit_is_renting:
  - Type: bool
  - Entity: benunit
  - Description: Whether this family is renting
  - Mean: 0.37220468299682785
  - Median: 0.0
  - Stddev: 0.4812236580276789
  - Non-zero count: 13116397.0


- benunit_tenure_type:
  - Type: Categorical
  - Entity: benunit
  - Description: Tenure type of the family's household


- benunit_weight:
  - Type: float
  - Entity: benunit
  - Description: Weight factor for the benefit unit
  - Mean: 2072.443922319295
  - Median: 1742.0
  - Stddev: 899.8135375976562
  - Non-zero count: 35239742.0


- eldest_adult_age:
  - Type: float
  - Entity: benunit
  - Description: Eldest adult age
  - Mean: -inf
  - Median: -inf
  - Stddev: nan
  - Non-zero count: 7532484.0


- eldest_child_age:
  - Type: float
  - Entity: benunit
  - Description: Eldest adult age
  - Mean: 47.662654737937636
  - Median: 48.0
  - Stddev: 18.706043243408203
  - Non-zero count: 35239742.0


- families:
  - Type: float
  - Entity: benunit
  - Description: Variable holding families
  - Mean: 1.0
  - Median: 1.0
  - Stddev: 0.0
  - Non-zero count: 35239742.0


- family_type:
  - Type: Categorical
  - Entity: benunit
  - Description: Family composition


- is_married:
  - Type: bool
  - Entity: benunit
  - Description: Whether the benefit unit adults are married
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- num_adults:
  - Type: int
  - Entity: benunit
  - Description: The number of children in the family
  - Mean: 1.4592390035091631
  - Median: 1.0
  - Stddev: 0.5370500709057318
  - Non-zero count: 34684149.0


- num_children:
  - Type: int
  - Entity: benunit
  - Description: The number of children in the family
  - Mean: 0.4027100425423092
  - Median: 0.0
  - Stddev: 0.8681971273016468
  - Non-zero count: 8311716.0


- relation_type:
  - Type: Categorical
  - Entity: benunit
  - Description: Whether single or a couple


- youngest_adult_age:
  - Type: float
  - Entity: benunit
  - Description: Eldest adult age
  - Mean: inf
  - Median: inf
  - Stddev: nan
  - Non-zero count: 34527020.0


- youngest_child_age:
  - Type: float
  - Entity: benunit
  - Description: Eldest adult age
  - Mean: 45.935262636145296
  - Median: 45.0
  - Stddev: 18.577775955200195
  - Non-zero count: 35239742.0


- BRMA:
  - Type: Categorical
  - Entity: household
  - Description: Broad Rental Market Area


- local_authority:
  - Type: Categorical
  - Entity: household
  - Description: The Local Authority for the household


- accommodation_type:
  - Type: Categorical
  - Entity: household
  - Description: Type of accommodation


- country:
  - Type: Categorical
  - Entity: household
  - Description: Country of the UK


- household_equivalisation_ahc:
  - Type: float
  - Entity: household
  - Description: Equivalisation factor to account for household composition, after housing costs
  - Mean: 0.754232968682252
  - Median: 0.5799999833106995
  - Stddev: 0.329802542924881
  - Non-zero count: 28023811.0


- household_equivalisation_bhc:
  - Type: float
  - Entity: household
  - Description: Equivalisation factor to account for household composition, before housing costs
  - Mean: 0.8237295858682046
  - Median: 0.6700000166893005
  - Stddev: 0.28699368238449097
  - Non-zero count: 28023811.0


- household_id:
  - Type: int
  - Entity: household
  - Description: ID for the household
  - Mean: 958404.5237316224
  - Median: 958313.664790494
  - Stddev: 554559.3671255285
  - Non-zero count: 28023811.0


- household_weight:
  - Type: float
  - Entity: household
  - Description: Weight factor for the household
  - Mean: 1938.489101178994
  - Median: 1639.0
  - Stddev: 836.5348510742188
  - Non-zero count: 28023811.0


- households:
  - Type: float
  - Entity: household
  - Description: Variable holding households
  - Mean: 1.0
  - Median: 1.0
  - Stddev: 0.0
  - Non-zero count: 28023811.0


- is_renting:
  - Type: bool
  - Entity: household
  - Description: Is renting
  - Mean: 0.27033642926010315
  - Median: 0.0
  - Stddev: 0.441824443144987
  - Non-zero count: 7575857.0


- is_shared_accommodation:
  - Type: bool
  - Entity: household
  - Description: Whether the household is shared accommodation
  - Mean: 0.0
  - Median: 0.0
  - Stddev: 0.0
  - Non-zero count: 0.0


- num_bedrooms:
  - Type: int
  - Entity: household
  - Description: The number of bedrooms in the house
  - Mean: 2.775578025415601
  - Median: 3.0
  - Stddev: 1.0121163086230742
  - Non-zero count: 28023811.0


- region:
  - Type: Categorical
  - Entity: household
  - Description: Region of the UK


- tenure_type:
  - Type: Categorical
  - Entity: household
  - Description: Tenure type of the household


- person_benunit_id:
  - Type: float
  - Entity: person
  - Description: Person's benefit unit ID
  - Mean: 959654.5877845084
  - Median: 959551.8093983312
  - Stddev: 554307.875
  - Non-zero count: 65614604.0


- person_household_id:
  - Type: float
  - Entity: person
  - Description: Person's household ID
  - Mean: 959642.929933708
  - Median: 959541.8093983312
  - Stddev: 554307.875
  - Non-zero count: 65614604.0


- role:
  - Type: Categorical
  - Entity: person
  - Description: Role (adult/child)
